github_cli: Command-line interface for GitHub
=============================================

Description
-----------

``gh`` is GitHub on the command line. It brings pull requests, issues, and
other GitHub concepts to the terminal next to where you are already
working with ``git`` and your code.

License
-------

MIT

Upstream Contact
----------------

https://github.com/cli/cli
